{% extends "base.html" %}

{% block content %}
<h1>{{ lokallag }}</h1>
    <dl><dt title="Tal på medlem som har betalt i fjor pluss nye medlem i år">Medlemar</dt>
        <dd>{{ medlem|length }}</dd>

        <dt title="Har betalt i inneverande år">Betalande medlem</dt>
        <dd>{{ betalt_count }}</dd>

        <dt title="Under 26 og har betalt for i år">Teljande medlem</dt>
        <dd>{{ teljande_count }}</dd>
    </dl>

    <h2>Medlemsliste</h2>
    <table>
        <thead><tr>
                <th>ID</th>
                <th>Namn</th>
                <th>Født</th>
                <th>mob/tlf</th>
                <th>Postnr</th>
                <th>Postadr</th>
                <th>Epost</th>
                <th>bet</th>
            </tr>
        </thead>
      <tbody>
  {% for m in medlem %}
          <tr>
            <td>{{ m.pk }}</td>
            <td>{{ m }}</td>
            <td>{{ m.fodt_farga|safe }}</td>
	    <td>{{ m.mobnr }}{% if m.heimenr %}, {{ m.heimenr }}{% endif %}</td>
            <td>{{ m.postnr }}</td>
            <td>{{ m.postadr }}</td>
            <td>{{ m.epost }}</td>
            <td>{{ m.har_betalt|yesno:"b,ub,?" }}</td>
          </tr>
  {% endfor %}
        </tbody>
      </table>

{% endblock %}
